Package: psychTools
Version: 2.6.4
Date: 2026-04-30
Title: Tools to Accompany the 'psych' Package for Psychological
        Research
Authors@R: person("William", "Revelle", role =c("aut","cre"), email="revelle@northwestern.edu", comment=c(ORCID  = "0000-0003-4880-9610") )
Description: Support functions,  data sets, and vignettes for the 'psych' package. Contains several of the biggest data sets for the 'psych' package as well as four vignettes. A few helper functions for file manipulation are included as well. For more information, see the <https://personality-project.org/r/> web page.
License: GPL (>= 2)
Imports: psych,foreign
Suggests: parallel, GPArotation, lavaan,knitr
Depends: R(>= 2.10)
LazyData: yes
ByteCompile: TRUE
VignetteBuilder: knitr
URL: https://personality-project.org/r/psych/
        https://personality-project.org/r/psych-manual.pdf
NeedsCompilation: no
Packaged: 2026-05-04 16:05:25 UTC; WR
Author: William Revelle [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4880-9610>)
Maintainer: William Revelle <revelle@northwestern.edu>
Repository: CRAN
Date/Publication: 2026-05-04 21:10:36 UTC
Built: R 4.5.2; ; 2026-05-04 22:44:46 UTC; unix
