#last modified December, 2024  by William Revelle 
#dropped the rtf functions
#added the various imports from stats, graphics, etc.
#importFrom(mnormt,rmnorm,sadmvn,dmnorm)
#importFrom(parallel,mclapply,mcmapply)
#importFrom(lattice,xyplot,strip.custom)
#importFrom(nlme,lme,VarCorr)
importFrom(graphics,plot,pairs,points,abline,arrows,axis,barplot,box,curve,hist,image,layout,legend, lines,mtext,par,persp,plot.new,plot.window, polygon,rect,segments,strheight,strwidth,text,axTicks,title,smoothScatter)

importFrom(stats,aov,cov,cor,var,sd,median,mad,cov2cor,biplot,loess,predict,predict.lm,rnorm,dnorm,rbinom,density, kmeans, lm,lm.fit,loadings,complete.cases, na.omit,na.fail,nlminb,optim, quantile,qnorm, pnorm,qqnorm,qqline,qqplot,pchisq,qchisq,qt,pt,dt,pf,qf,ppoints,p.adjust,optimize,residuals,spline,symnum,terms,weighted.mean,promax,varimax,uniroot)

#importFrom(datasets,USArrests,attitude,Harman23.cor,Harman74.cov,ability.cov,iris)
importFrom(utils,head,tail,read.table,write.table,read.fwf,stack,example,download.file,getFromNamespace,untar,unzip,View)

importFrom(grDevices,colorRampPalette,topo.colors,devAskNewPage,dev.flush,dev.hold, palette, grey,rainbow,rgb,col2rgb,trans3d,adjustcolor)
#importFrom(rtf, RTF, addHeader,addTable, addText,addPageBreak,addNewLine, done)
#importFrom(methods,new)

importFrom(tools,file_ext,Rd2HTML)

importFrom(foreign,read.spss,read.xport,read.systat)
#importFrom(psych,statsBy,cs,setCor, mediate,corPlot, omega, scatterHist,dia.ellipse)

#S3method(print,psych)


 export(
 combineMatrices,
 cor2latex,
 #cor2rtf,
 df2latex,
 #df2rtf,

 dfOrder,

 fa2latex,
 #fa2rtf,
 
 fileCreate,
 filesInfo,
 filesList,
 fileScan,
 hare,
 ICC2latex,

 irt2latex,

 omega2latex,
rd2html,
 read.clipboard,
 read.clipboard.csv,
 read.clipboard.fwf,
 read.clipboard.tab,
 read.clipboard.lower,
 read.clipboard.upper,
 read.file,
 read.file.csv,
 read.https,
 recode,
 rearrange,
vJoin,
selectBy,
splitBy,
 write.file,
 write.file.csv,
 wide2long
 )
